/* $Id: $
 *
 * RSSDialog.cpp
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */

#include "iup.h"
#include "RSSDialog.h"


RSSDialog::RSSDialog(RSSWidget *childWidget, std::string title)
  : m_title(title), RSSWidget("RSSDialog"), m_menu(0)
{
  addSubWidget(childWidget);
}


RSSDialog::~RSSDialog()
{
  if(m_menu)
  {
    delete m_menu;
    m_menu = 0;
  }
}


void RSSDialog::setTitle(std::string title)
{
  m_title = title;
  setAttribute("TITLE", m_title);
}


bool RSSDialog::addMenu(RSSMenu *menu)
{
  if(!menu)
    return false;

  Ihandle *menuHandle = (Ihandle *)menu->getHandle();
  if(m_handle && menuHandle)
    setAttribute(IUP_MENU, menu->getWidgetId());
  else
    m_menu = menu;

  return true;
}


bool RSSDialog::createLowLevelWidget()
{
  RSSWidget *child = *(m_subWidgets.begin());
  Ihandle *childHandle = (Ihandle *)child->getHandle();
  if(!childHandle)
    return false;

  m_handle = IupDialog(childHandle);
  if(m_handle)
  {
    m_alreadyAddedSubWidgets.insert(child->getWidgetId());
    setAttribute("TITLE", m_title);

    if(m_menu)
    {
      m_menu->create();
      Ihandle *menuHandle = (Ihandle *)m_menu->getHandle();
      if(menuHandle)
        setAttribute(IUP_MENU, m_menu->getWidgetId());
    }
  }
  return m_handle != 0;
}


