/* $Id: $
 *
 * RSSList.cpp
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */

#include "iup.h"
#include "RSSList.h"


RSSList::RSSList()
  : RSSWidget("RSSList"), m_nofItems(0), m_multiSelectFlag(false)
{
}


RSSList::~RSSList()
{
}


int RSSList::getNumberOfItems()
{
  return m_nofItems;
}


void RSSList::setNumberOfItems(int nofItems)
{
  int i;
  int oldNofItems = m_nofItems;

  m_nofItems = nofItems;
  if(nofItems < oldNofItems)
  {
    for(i = nofItems + 1; i <= oldNofItems; i++)
    {
      char buf[10];
      sprintf(buf, "%d", i);
      deleteAttribute(buf);
    }
  }
  else if(nofItems > oldNofItems)
  {
    for(i = oldNofItems + 1; i <= nofItems; i++)
      setItem(i, "");
  }
}


bool RSSList::isDropDown()
{
  return getAttribute(IUP_DROPDOWN) == IUP_YES;
}


void RSSList::setDropDown(bool dropDownFlag)
{
  setAttribute(IUP_DROPDOWN, dropDownFlag ? IUP_YES : IUP_NO);
}


void RSSList::setNumberOfVisibleItems(int newNofVisibleItems)
{
  char buf[10];
  sprintf(buf, "%d", newNofVisibleItems);
  setAttribute(IUP_VISIBLE_ITEMS, buf);
}


int RSSList::getNumberOfVisibleItems()
{
  return atoi(getAttribute(IUP_VISIBLE_ITEMS).c_str());
}


bool RSSList::isMultiSelect()
{
  return m_multiSelectFlag;
}


void RSSList::setMultiSelect(bool multiSelectFlag)
{
  setAttribute(IUP_MULTIPLE, multiSelectFlag ? IUP_YES : IUP_NO);
  m_multiSelectFlag = multiSelectFlag;
}


int RSSList::getSelectedItem()
{
  std::set<int> indices = getSelectedItems();
  return indices.size() > 0 ? *(indices.begin()) : -1;
}


std::set<int> RSSList::getSelectedItems()
{
  std::set<int> indices;

  // This function only works when the GUI element is already mapped to
  // a native element...
  create();

  if(isMultiSelect())
  {
    std::string a = getAttribute(IUP_VALUE);
    int len = a.size();
    for(int i = 0; i < len; i++)
    {
      if(a[i] == '+')
        indices.insert(i);
    }
  }
  else
  {
    // single selection mode
    indices.insert(atoi(getAttribute(IUP_VALUE).c_str()));
  }

  return indices;
}


void RSSList::setSelectedItem(int index, bool selectionFlag)
{
  std::set<int> indices = getSelectedItems();

  std::set<int>::iterator it = indices.find(index);
  bool found = it != indices.end();

  if(found && !selectionFlag)
    indices.erase(it);
  else if(!found && selectionFlag)
    indices.insert(index);

  setSelection(indices);
}


void RSSList::setSelection(std::set<int> &indices)
{
  if(isMultiSelect())
  {
    std::string s;
    for(int i = 0; i < m_nofItems; i++)
      s += (indices.find(i+1) != indices.end() ? '+' : '-');

    setAttribute(IUP_VALUE, s);
  }
  else
  {
    // single selection - value is simply an integer...
    char buf[10];
    int index = indices.size() > 0 ? *(indices.begin()) : 0;
    sprintf(buf, "%d", index);
    setAttribute(IUP_VALUE, buf);
  }
}


int RSSList::addItem(std::string newItem)
{
  int newIndex;
  char buf[10];

  m_nofItems++;
  newIndex = m_nofItems;

  sprintf(buf, "%d", newIndex);
  setAttribute(buf, newItem);

  return newIndex;
}


void RSSList::setItem(int index, std::string newItem)
{
  char buf[10];

  sprintf(buf, "%d", index);
  setAttribute(buf, newItem);
}


std::string RSSList::getItem(int index)
{
  char buf[10];

  sprintf(buf, "%d", index);
  return getAttribute(buf);
}


RSSCallbackType RSSList::getCallbackType()
{
  return RSSGUI_LIST_CALLBACK;
}


bool RSSList::createLowLevelWidget()
{
  m_handle = IupList((char *)getDefaultActionId().c_str());
  return m_handle != 0;
}


