/* $Id: $
 *
 * RSSMatrix.cpp
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */

#include "iup.h"
#include "iupcontrols.h"
#include "RSSMatrix.h"


RSSMatrix::RSSMatrix() : RSSWidget("RSSMatrix")
{
}


RSSMatrix::~RSSMatrix()
{
}


void RSSMatrix::redraw()
{
  setAttribute(IUP_REDRAW, "ALL");
}


unsigned int RSSMatrix::getNumberOfColumns()
{
  unsigned int result = 0;

  std::string nofCols = getAttribute(IUP_NUMCOL);
  result = atoi(nofCols.c_str());

  return result;
}


unsigned int RSSMatrix::getNumberOfRows()
{
  unsigned int result = 0;

  std::string nofRows = getAttribute(IUP_NUMLIN);
  result = atoi(nofRows.c_str());

  return result;
}


void RSSMatrix::setNumberOfColumns(unsigned int nofCols)
{
  char buf[10];
  sprintf(buf, "%d", nofCols);

  setAttribute(IUP_NUMCOL, buf);
}


void RSSMatrix::setNumberOfRows(unsigned int nofRows)
{
  char buf[10];
  sprintf(buf, "%d", nofRows);

  setAttribute(IUP_NUMLIN, buf);
}


unsigned int RSSMatrix::getNumberOfVisibleColumns()
{
  return atoi(getAttribute(IUP_NUMCOL_VISIBLE).c_str());
}


unsigned int RSSMatrix::getNumberOfVisibleRows()
{
  return atoi(getAttribute(IUP_NUMLIN_VISIBLE).c_str());
}


void RSSMatrix::setNumberOfVisibleColumns(unsigned int nofCols)
{
  char buf[10];
  sprintf(buf, "%d", nofCols);

  setAttribute(IUP_NUMCOL_VISIBLE, buf);
}


void RSSMatrix::setNumberOfVisibleRows(unsigned int nofRows)
{
  char buf[10];
  sprintf(buf, "%d", nofRows);

  setAttribute(IUP_NUMLIN_VISIBLE, buf);
}


void RSSMatrix::setColumnWidth(unsigned int column, unsigned int width)
{
  char buf1[15];
  char buf2[15];
  sprintf(buf1, "WIDTH%d", column);
  sprintf(buf2, "%d", width * 4 + 3);

  setAttribute(buf1, buf2);
}


void RSSMatrix::setRowHeight(unsigned int row, unsigned int height)
{
  char buf1[15];
  char buf2[15];
  sprintf(buf1, "HEIGHT%d", row);
  sprintf(buf2, "%d", height * 8);

  setAttribute(buf1, buf2);
}


unsigned int RSSMatrix::addRowAtTheEnd()
{
  unsigned int lastIndex = getNumberOfRows();
  unsigned int newIndex = lastIndex + 1;

  setNumberOfRows(newIndex);
  return newIndex;
}


void RSSMatrix::addRow(unsigned int index)
{
  char buf[10];
  sprintf(buf, "%d", index);

  setAttribute(IUP_ADDLIN, buf);
}


void RSSMatrix::addRows(unsigned int startIndex, unsigned int numberOfNewRows)
{
  char buf[10];
  sprintf(buf, "%d-%d", startIndex, numberOfNewRows);

  setAttribute(IUP_ADDLIN, buf);
}


void RSSMatrix::setColumnTitle(unsigned int column, std::string title)
{
  setCellValue(column, 0, title);
  setColumnWidth(column, title.size());
}


void RSSMatrix::setRowTitle(unsigned int row, std::string title)
{
  setCellValue(0, row, title);
}


void RSSMatrix::setCellValue(unsigned int column, unsigned int row, std::string value)
{
  char buf[15];
  sprintf(buf, "%d:%d", row, column);

  setAttribute(buf, value);
}


void RSSMatrix::setSelectionMode(RSSMatrixSelectionMode selectionMode)
{
  std::string iupMode = "NO";

  if(selectionMode == MSM_Columns)
    iupMode = "COL";
  else if(selectionMode == MSM_Rows)
    iupMode = "LIN";
  else if(selectionMode == MSM_ColumnsAndRows)
    iupMode = "LINCOL";
  else if(selectionMode == MSM_Cell)
    iupMode = "CELL";

  setAttribute(IUP_MARK_MODE, iupMode);
}


void RSSMatrix::setMultipleSelectionMode(bool flag)
{
  std::string iup = flag ? IUP_YES : IUP_NO;
  setAttribute(IUP_MULTIPLE, iup);
}


std::string RSSMatrix::getCellValue(unsigned int column, unsigned int row)
{
  char buf[15];
  sprintf(buf, "%d:%d", column, row);

  return getAttribute(buf);
}


bool RSSMatrix::createLowLevelWidget()
{
  m_handle = IupMatrix((char *)getDefaultActionId().c_str());
  return m_handle != 0;
}


