/* $Id: $
 *
 * RSSTab.cpp
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */

#include <stdarg.h>
#include "iup.h"
#include "iupcontrols.h"
#include "RSSTab.h"


RSSTab::RSSTab(RSSTabType tabType, RSSWidget *childWidget, ...)
  : RSSWidget("RSSTab"), m_tabType(tabType)
{
  va_list args;

  va_start(args, childWidget);
  RSSWidget *widget = childWidget;
  while(widget)
  {
    if(widget->getAttribute(ICTL_TABTITLE) == "")
      widget->setAttribute(ICTL_TABTITLE, widget->getWidgetId());

    addSubWidget(widget);
    widget = va_arg(args, RSSWidget *);
  }
  va_end(args);
}


RSSTab::~RSSTab()
{
}


bool RSSTab::createLowLevelWidget()
{
  // Unfortunetly tab elements cannot be appended later, so
  // we must use the constructor function...
  int nofSubWidgets = m_subWidgets.size();
  if(nofSubWidgets == 1)
    m_handle = IupTabs((Ihandle *)m_subWidgets[0]->getHandle(), 0);
  else if(nofSubWidgets == 2)
  {
    m_handle = IupTabs((Ihandle *)m_subWidgets[0]->getHandle(),
                       (Ihandle *)m_subWidgets[1]->getHandle(),
                       0);
  }
  else if(nofSubWidgets == 3)
  {
    m_handle = IupTabs((Ihandle *)m_subWidgets[0]->getHandle(),
                       (Ihandle *)m_subWidgets[1]->getHandle(),
                       (Ihandle *)m_subWidgets[2]->getHandle(),
                       0);
  }
  else if(nofSubWidgets == 4)
  {
    m_handle = IupTabs((Ihandle *)m_subWidgets[0]->getHandle(),
                       (Ihandle *)m_subWidgets[1]->getHandle(),
                       (Ihandle *)m_subWidgets[2]->getHandle(),
                       (Ihandle *)m_subWidgets[3]->getHandle(),
                       0);
  }
  else if(nofSubWidgets == 5)
  {
    m_handle = IupTabs((Ihandle *)m_subWidgets[0]->getHandle(),
                       (Ihandle *)m_subWidgets[1]->getHandle(),
                       (Ihandle *)m_subWidgets[2]->getHandle(),
                       (Ihandle *)m_subWidgets[3]->getHandle(),
                       (Ihandle *)m_subWidgets[4]->getHandle(),
                       0);
  }
  else if(nofSubWidgets == 6)
  {
    m_handle = IupTabs((Ihandle *)m_subWidgets[0]->getHandle(),
                       (Ihandle *)m_subWidgets[1]->getHandle(),
                       (Ihandle *)m_subWidgets[2]->getHandle(),
                       (Ihandle *)m_subWidgets[3]->getHandle(),
                       (Ihandle *)m_subWidgets[4]->getHandle(),
                       (Ihandle *)m_subWidgets[5]->getHandle(),
                       0);
  }
  else if(nofSubWidgets == 7)
  {
    m_handle = IupTabs((Ihandle *)m_subWidgets[0]->getHandle(),
                       (Ihandle *)m_subWidgets[1]->getHandle(),
                       (Ihandle *)m_subWidgets[2]->getHandle(),
                       (Ihandle *)m_subWidgets[3]->getHandle(),
                       (Ihandle *)m_subWidgets[4]->getHandle(),
                       (Ihandle *)m_subWidgets[5]->getHandle(),
                       (Ihandle *)m_subWidgets[6]->getHandle(),
                       0);
  }
  else if(nofSubWidgets == 8)
  {
    m_handle = IupTabs((Ihandle *)m_subWidgets[0]->getHandle(),
                       (Ihandle *)m_subWidgets[1]->getHandle(),
                       (Ihandle *)m_subWidgets[2]->getHandle(),
                       (Ihandle *)m_subWidgets[3]->getHandle(),
                       (Ihandle *)m_subWidgets[4]->getHandle(),
                       (Ihandle *)m_subWidgets[5]->getHandle(),
                       (Ihandle *)m_subWidgets[6]->getHandle(),
                       (Ihandle *)m_subWidgets[7]->getHandle(),
                       0);
  }
  else if(nofSubWidgets == 9)
  {
    m_handle = IupTabs((Ihandle *)m_subWidgets[0]->getHandle(),
                       (Ihandle *)m_subWidgets[1]->getHandle(),
                       (Ihandle *)m_subWidgets[2]->getHandle(),
                       (Ihandle *)m_subWidgets[3]->getHandle(),
                       (Ihandle *)m_subWidgets[4]->getHandle(),
                       (Ihandle *)m_subWidgets[5]->getHandle(),
                       (Ihandle *)m_subWidgets[6]->getHandle(),
                       (Ihandle *)m_subWidgets[7]->getHandle(),
                       (Ihandle *)m_subWidgets[8]->getHandle(),
                       0);
  }
  else if(nofSubWidgets == 10)
  {
    m_handle = IupTabs((Ihandle *)m_subWidgets[0]->getHandle(),
                       (Ihandle *)m_subWidgets[1]->getHandle(),
                       (Ihandle *)m_subWidgets[2]->getHandle(),
                       (Ihandle *)m_subWidgets[3]->getHandle(),
                       (Ihandle *)m_subWidgets[4]->getHandle(),
                       (Ihandle *)m_subWidgets[5]->getHandle(),
                       (Ihandle *)m_subWidgets[6]->getHandle(),
                       (Ihandle *)m_subWidgets[7]->getHandle(),
                       (Ihandle *)m_subWidgets[8]->getHandle(),
                       (Ihandle *)m_subWidgets[9]->getHandle(),
                       0);
  }
  else
    return false;

  if(m_handle)
  {
    for(int i = 0; i < nofSubWidgets; i++)
      m_alreadyAddedSubWidgets.insert(m_subWidgets[i]->getWidgetId());
  }

  return m_handle != 0;
}


