/* $Id: $
 *
 * RSSText.cpp
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */

#include "iup.h"
#include "RSSText.h"


RSSText::RSSText()
  : RSSWidget("RSSText")
{
}


RSSText::~RSSText()
{
}


std::string RSSText::getText()
{
  // Only works after show() or create()...
  create();
  return getAttribute(IUP_VALUE);
}


void RSSText::setText(std::string newText)
{
  setAttribute(IUP_VALUE, newText);
}


void RSSText::append(std::string textToAppend)
{
  // IuP does not implement this operation for text controls - only for multiline controls...
  //setAttribute(IUP_APPEND, textToAppend);
  std::string text = getText();
  text += textToAppend;
  setText(text);
}


std::string RSSText::getSelectedText()
{
  return getAttribute(IUP_SELECTEDTEXT);
}


void RSSText::setBorder(bool borderFlag)
{
  setAttribute(IUP_BORDER, borderFlag ? IUP_YES : IUP_NO);
}


int RSSText::getMaxSize()
{
  return atoi(getAttribute(IUP_NC).c_str());
}


void RSSText::setMaxSize(int newMaxSize)
{
  char buf[10];
  sprintf(buf, "%d", newMaxSize);

  setAttribute(IUP_NC, buf);
}


int RSSText::getSize()
{
  return atoi(getAttribute(IUP_SIZE).c_str()) / 4;
}


void RSSText::setSize(int newSize)
{
  char buf[10];
  sprintf(buf, "%dx", newSize * 4);

  setAttribute(IUP_SIZE, buf);
}


int RSSText::getCursorPosition()
{
  return atoi(getAttribute(IUP_CARET).c_str());
}


void RSSText::setCursorPosition(int newCursorPosition)
{
  char buf[10];
  sprintf(buf, "%d", newCursorPosition);

  setAttribute(IUP_CARET, buf);
}


bool RSSText::isReadOnly()
{
  return getAttribute(IUP_READONLY) == IUP_YES ? true : false;
}


void RSSText::setReadOnly(bool readOnlyFlag)
{
  setAttribute(IUP_READONLY, readOnlyFlag ? IUP_YES : IUP_NO);
}


bool RSSText::createLowLevelWidget()
{
  m_handle = IupText((char *)getDefaultActionId().c_str());
  return m_handle != 0;
}

