/* $Id: $
 *
 * RSSWizard.cpp
 *
 * This class represents a wizard dialog
 * Attention: RSSWizard is NOT derived from RSSWidget!
 * If you want to use this class, you have to subclass it!
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */


#include <stdio.h>
#include <stdarg.h>

#include "RSSWizard.h"
#include "RSSButton.h"
#include "RSSFill.h"
#include "RSSHBox.h"
#include "RSSVBox.h"


RSSWizard::RSSWizard(std::string wizardTitle)
  : m_currentPage(-1)
{
}


RSSWizard::~RSSWizard()
{
  std::vector<RSSDialog *>::iterator it;
  for(it = m_dialogs.begin(); it != m_dialogs.end(); it++)
    delete *it;
}


void RSSWizard::addPage(std::string pageTitle, RSSWidget *pageWidget)
{
  int pageNumber = m_dialogs.size();
  createDialogForPage(pageNumber, pageTitle, pageWidget);
}


void RSSWizard::show()
{
  if(m_currentPage == -1)
    m_currentPage = 0;

  if(m_currentPage < m_dialogs.size())
    m_dialogs[m_currentPage]->show();
}


void RSSWizard::hide()
{
  if(m_currentPage >= 0 && m_currentPage < m_dialogs.size())
    m_dialogs[m_currentPage]->hide();
}


void RSSWizard::onOk(int pageNumber)
{
  // Default: Do nothing...
  pageNumber = pageNumber;  // Avoid a compiler warning
}


void RSSWizard::onCancel(int pageNumber)
{
  // Default: Do nothing...
  pageNumber = pageNumber;  // Avoid a compiler warning
}


void RSSWizard::createDialogForPage(int pageNumber, std::string pageTitle, RSSWidget *pageWidget)
{
  RSSButton *buttonPrev   = new RSSButton("Prev");
  RSSButton *buttonNext   = new RSSButton("Next");
  RSSButton *buttonOk     = new RSSButton("OK");
  RSSButton *buttonCancel = new RSSButton("Cancel");

  RSSHBox *boxButtons = new RSSHBox(
    new RSSFill(), new RSSFill(), buttonPrev, buttonNext, new RSSFill(), buttonOk, buttonCancel, 0);

  RSSVBox *pageBox = new RSSVBox(pageWidget, new RSSFill(), boxButtons, 0);

  RSSDialog *dialog = new RSSDialog(pageBox, pageTitle);
  m_dialogs.push_back(dialog);

  rssRegisterEvent(buttonPrev,   RSSWizard::buttonPrevEvent);
  rssRegisterEvent(buttonNext,   RSSWizard::buttonNextEvent);
  rssRegisterEvent(buttonOk,     RSSWizard::buttonOkEvent);
  rssRegisterEvent(buttonCancel, RSSWizard::buttonCancelEvent);
}


int RSSWizard::buttonPrevEvent(RSSEvent &event)
{
  if(m_currentPage > 0)
  {
    m_dialogs[m_currentPage]->hide();
    m_currentPage--;
    m_dialogs[m_currentPage]->show();
  }
  return RSSGUIDEFAULT;
}


int RSSWizard::buttonNextEvent(RSSEvent &event)
{
  if(m_currentPage + 1 < m_dialogs.size())
  {
    if(m_currentPage != -1)
      m_dialogs[m_currentPage]->hide();
    m_currentPage++;
    m_dialogs[m_currentPage]->show();
  }

  return RSSGUIDEFAULT;
}


int RSSWizard::buttonOkEvent(RSSEvent &event)
{
  if(m_currentPage >= 0 && m_currentPage < m_dialogs.size())
    m_dialogs[m_currentPage]->hide();

  onOk(m_currentPage);
  return RSSGUIDEFAULT;
}


int RSSWizard::buttonCancelEvent(RSSEvent &event)
{
  if(m_currentPage >= 0 && m_currentPage < m_dialogs.size())
    m_dialogs[m_currentPage]->hide();

  onCancel(m_currentPage);
  return RSSGUIDEFAULT;
}

