/* $Id: $
 *
 * RSSList.h
 *
 * This class represents a list widget
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */

#ifndef RSSLIST_H
#define RSSLIST_H

#pragma warning(disable:4786)

#include <set>
#include "RSSGuiDeclSpec.h"
#include "RSSWidget.h"


class RSS_GUI_DECL_SPEC RSSList : public RSSWidget
{
  public:
    RSSList();
    virtual ~RSSList();

    virtual int  getNumberOfItems();
    virtual void setNumberOfItems(int newNofItems);

    virtual bool isDropDown();
    virtual void setDropDown(bool dropDownFlag);
    virtual void setNumberOfVisibleItems(int newNofVisibleItems); // Only in DropDown mode
    virtual int  getNumberOfVisibleItems(); // Only in DropDown mode

    virtual bool isMultiSelect();
    virtual void setMultiSelect(bool multiSelectFlag);

    virtual int         addItem(std::string newItem); // returns the new index
    virtual void        setItem(int index, std::string newItem);
    virtual std::string getItem(int index);

    virtual int           getSelectedItem();  // Works in single mode
    virtual std::set<int> getSelectedItems(); // Works in both, single mode and multi select mode

    virtual void  setSelectedItem(int index, bool selectionFlag);
    virtual void  setSelection(std::set<int> &indices); // selects the specified items and deselects all others

    virtual RSSCallbackType getCallbackType();

  protected:
    bool createLowLevelWidget();

  private:
    int  m_nofItems;
    bool m_multiSelectFlag;
};


#endif

