/* $Id: $
 *
 * This class represents a table widget
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */

#ifndef RSSMATRIX_H
#define RSSMATRIX_H

#include "RSSGuiDeclSpec.h"
#include "RSSWidget.h"


enum RSSMatrixSelectionMode
{
  MSM_Nothing,
  MSM_Columns,
  MSM_Rows,
  MSM_ColumnsAndRows,
  MSM_Cell
};


class RSS_GUI_DECL_SPEC RSSMatrix : public RSSWidget
{
  public:
    RSSMatrix();
    virtual ~RSSMatrix();

    virtual void redraw();

    virtual unsigned int getNumberOfColumns();
    virtual unsigned int getNumberOfRows();
    virtual void setNumberOfColumns(unsigned int nofCols);
    virtual void setNumberOfRows(unsigned int nofRows);

    virtual unsigned int getNumberOfVisibleColumns();
    virtual unsigned int getNumberOfVisibleRows();
    virtual void setNumberOfVisibleColumns(unsigned int nofCols);
    virtual void setNumberOfVisibleRows(unsigned int nofRows);

    virtual void setColumnWidth(unsigned int column, unsigned int width);
    virtual void setRowHeight(unsigned int row, unsigned int height);

    virtual unsigned int addRowAtTheEnd();  // returns the index of the new row
    virtual void addRow(unsigned int index);
    virtual void addRows(unsigned int startIndex, unsigned int numberOfNewRows);

    virtual void setColumnTitle(unsigned int column, std::string title);
    virtual void setRowTitle(unsigned int row, std::string title);

    virtual void setCellValue(unsigned int column, unsigned int row, std::string value);
    virtual std::string getCellValue(unsigned int column, unsigned int row);

    virtual void setSelectionMode(RSSMatrixSelectionMode selectionMode);
    virtual void setMultipleSelectionMode(bool flag);

  protected:
    bool createLowLevelWidget();
};


#endif


