/* $Id: $
 *
 * RSSWidget.h
 *
 * This class is the base class of all concrete widget classes...
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */

#ifndef RSSWIDGET_H
#define RSSWIDGET_H

#pragma warning(disable:4786)

#include <string>
#include <list>
#include <vector>
#include <set>
#include "RSSGuiDeclSpec.h"


enum RSS_GUI_DECL_SPEC RSSCallbackType
{
  RSSGUI_GLOBAL_CALLBACK = 0,
  RSSGUI_LIST_CALLBACK
};


struct RSS_GUI_DECL_SPEC RSSAttr
{
  std::string attribute;
  std::string value;
};

typedef RSS_GUI_DECL_SPEC std::list<RSSAttr> RSSAttrList;

class RSS_GUI_DECL_SPEC RSSWidget
{
  public:
    RSSWidget(std::string widgetType, std::string widgetId = "");
    virtual ~RSSWidget();

    void *getHandle(); // returns the Ihandle * of the underlying IuP object

    std::string getWidgetId();
    void        setWidgetId(std::string newWidgetId);

    std::string getDefaultActionId();
    std::string getWidgetType();

    // An expandable widget gets resized when its parent widget gets resized...
    virtual void setExpandFlag(bool expandable);

    virtual void setToolTip(std::string newToolTip);

    // The title of the widget if it is an element in a tab widget...
    virtual void setTabTitle(std::string newTabTitle);

    // ATTENTION: setFocus() only works after show() or create()!
    void setFocus(); // sets the focus to this widget (this widget will receive keybord events)

    virtual void        setAttribute(std::string attr, std::string value);
    virtual std::string getAttribute(std::string attr);
    virtual void        deleteAttribute(std::string attr);

    virtual void show();
    virtual void hide();

    virtual std::vector<RSSWidget *> &getSubWidgets();
    virtual void addSubWidget(RSSWidget *widget);
    virtual void addSubWidgets(RSSWidget *widget, ...); // 0 terminated list of widgets!
    virtual void detachSubWidget(RSSWidget *widget);

    virtual bool create();

    virtual RSSCallbackType getCallbackType();

  protected:
    // override this method in all specialized widget classes
    // return true, if everything is fine and false if an error occured
    // set m_handle properly!
    virtual bool createLowLevelWidget() = 0;

    std::string  m_widgetId;
    std::string  m_widgetType;
    void        *m_handle;
    std::string  m_defaultActionId;

    RSSAttrList              m_attributes;
    std::vector<RSSWidget *> m_subWidgets;
    std::set<std::string>    m_alreadyAddedSubWidgets;
};


#endif

