/* $Id: $
 *
 * RSSWizard.h
 *
 * This class represents a wizard dialog
 * Attention: RSSWizard is NOT derived from RSSWidget!
 * If you want to use this class, you have to subclass it!
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */

#ifndef RSSWIZARD_H
#define RSSWIZARD_H

#include <vector>
#include <string>

#include "RSSGuiDeclSpec.h"
#include "RSSWidget.h"
#include "RSSEvent.h"
#include "RSSDialog.h"


class RSS_GUI_DECL_SPEC RSSWizard : public RSSEventHandler
{
  public:
    RSSWizard(std::string wizardTitle);
    virtual ~RSSWizard();

    void addPage(std::string pageTitle, RSSWidget *pageWidget);

    virtual void show();
    virtual void hide();

  protected:
    // Override these functions in you subclass of class RSSWizard
    // to handle clicks on the OK or the CANCEL buttons.
    // These functions receive the pageNumber (starting with 0)
    // of the page on which the user clicked the button...
    virtual void onOk(int pageNumber);
    virtual void onCancel(int pageNumber);

  private:
    std::vector<RSSDialog *> m_dialogs;
    int                      m_currentPage;

    void createDialogForPage(int pageNumber, std::string pageTitle, RSSWidget *pageWidget);

    int buttonPrevEvent(RSSEvent &event);
    int buttonNextEvent(RSSEvent &event);
    int buttonOkEvent(RSSEvent &event);
    int buttonCancelEvent(RSSEvent &event);
};


#endif
