/* $Id: $
 *
 * simple example for using RSSGui...
 *
 * Author: Danny Reinhold / Reinhold Software Services
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without restriction,
 * including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software,
 * and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions: 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE. 
 */

#include "RSSGui.h"


class MyDialog : RSSEventHandler
{
public:
  int button1Event(RSSEvent &event)
  {
    static bool flag = false;
    flag = !flag;  // toggle flag

    ((RSSButton *)(event.getWidget()))->setLabel(flag ? "text1" : "text2");
    return RSSGUIDEFAULT;
  }


  int button2Event(RSSEvent &event)
  {
    return RSSGUICLOSE;
  }


  int menuExitEvent(RSSEvent &event)
  {
    return RSSGUICLOSE;
  }


  void doIt()
  {
    // create a simple dialog with some widgets...
    RSSButton *b1 = new RSSButton("Button 1");
    RSSButton *b2 = new RSSButton("Close");
    RSSVBox *v1 = new RSSVBox(b1, b2, 0);
    RSSDialog *d1 = new RSSDialog(v1, "RSSGui Example");

    // set tool tips for the buttons
    b1->setToolTip("A cool button");
    b2->setToolTip("Close this wunderful application");

    RSSItem *item1 = new RSSItem("New...");
    RSSItem *item2 = new RSSItem("Open...");
    RSSItem *item3 = new RSSItem("Save");
    RSSSeparator *sep1 = new RSSSeparator();
    RSSItem *item4 = new RSSItem("Exit");

    RSSMenu *menu1 = new RSSMenu(item1, item2, item3, sep1, item4, 0);
    RSSSubmenu *subMenu1 = new RSSSubmenu("File", menu1);

    RSSMenu *mainMenu = new RSSMenu(subMenu1, 0);
    d1->addMenu(mainMenu);

    // show the dialog
    d1->show();

    // register the event handlers
    rssRegisterEvent(b1, MyDialog::button1Event);
    rssRegisterEvent(b2, MyDialog::button2Event);
    rssRegisterEvent(item4, MyDialog::menuExitEvent);

    // Start the main event loop
    RSSEventManager *eventManager = RSSEventManager::getInstance();
    eventManager->mainLoop();

    delete d1;
  }
};


int main()
{
  rssGuiInit();

  MyDialog d;
  d.doIt();

  rssGuiRelease();
  return 0;
}

